window.Gleam.initSearch([{"doc":"feather","title":"feather","content":"# feather\n\n[![Package Version](https://img.shields.io/hexpm/v/feather)](https://hex.pm/packages/feather)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/feather/)\n\n```sh\ngleam add feather\n```\nAdd the following fields to your gleam.toml file:\n\n```toml\n# this can of course be anything you like\nmigrations_dir = &quot;./priv/migrations&quot;\nschemafile = &quot;./schema.sql&quot;\n```\n\nThen run the command `gleam run -m feather -- new &quot;Initial schema migration&quot;` and make any changes you like.\n\nRunning the command `gleam run -m feather -- schema` will create the file ./schema.sql, (or whatever you set in your gleam.toml) with the schema of your database after all migrations have been applied.\n\n```gleam\nimport feather\nimport gleam/result\nimport gleam/erlang\nimport sqlight\n\npub fn main() {\n  let assert Ok(priv_dir) = erlang.priv_directory(&quot;my_module_name&quot;)\n  use migrations &lt;- result.try(feather.get_migrations(priv_dir &lt;&gt; &quot;/migrations&quot;))\n  use connection &lt;- feather.connect(feather.Config(..feather.default_config(), file: &quot;./database.db&quot;))\n  feather.migrate(migrations, on: connection)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/feather&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"feather/migrate","title":"Migration","content":"pub type Migration {\n  Migration(id: Int, up: String)\n}\n Migrations with an id and a sql script\n\nMigration(id: Int, up: String)\n\n\nSynonyms:\nfeather/migrate.Migration\nfeather/migrate Migration","url":"feather/migrate.html#Migration"},{"doc":"feather/migrate","title":"MigrationError","content":"pub type MigrationError {\n  DirectoryNotExist(String)\n  InvalidMigrationName(String)\n  InvalidMigrationId(String)\n  TransactionError(sqlight.Error)\n  MigrationsTableError(sqlight.Error)\n  MigrationScriptError(Int, sqlight.Error)\n}\n Migration error type\nDirectoryNotExist(String)\n Folder that you gave does not exist\n\nInvalidMigrationName(String)\n The migration script file name is not valid\n\nInvalidMigrationId(String)\n The migration script file has a non-integer id\n\nTransactionError(sqlight.Error)\n Error starting or comitting the migration transaction\n\nMigrationsTableError(sqlight.Error)\n Error reading/writing/creating the transactions table\n\nMigrationScriptError(Int, sqlight.Error)\n Error applying the migrations script\n\nSynonyms:\nfeather/migrate.MigrationError\nfeather/migrate MigrationError","url":"feather/migrate.html#MigrationError"},{"doc":"feather/migrate","title":"get_migrations","content":"pub fn get_migrations(\n  in directory: String,\n) -&gt; Result(List(Migration), MigrationError)\n Get a list of migrations from a folder in the filesystem\n migration files *must* end in .sql and start with an integer id followed by an underscore\n example: 0000001_init.sql\n\n you could store these in the priv directory if you like, that&#39;s probably the best way\nSynonyms:\nfeather/migrate.get_migrations\nfeather/migrate get_migrations","url":"feather/migrate.html#get_migrations"},{"doc":"feather/migrate","title":"main","content":"pub fn main() -&gt; Nil\n Runs the feather cli to generate new migrations and dump the schema\n you probably don&#39;t wanna run this yourself...\n run `gleam run -m feather` to find out more\nSynonyms:\nfeather/migrate.main\nfeather/migrate main","url":"feather/migrate.html#main"},{"doc":"feather/migrate","title":"migrate","content":"pub fn migrate(\n  migrations: List(Migration),\n  on connection: Connection,\n) -&gt; Result(Nil, MigrationError)\n Pass in a list of migrations and a sqlight connection\n\nSynonyms:\nfeather/migrate.migrate\nfeather/migrate migrate","url":"feather/migrate.html#migrate"},{"doc":"feather/migrate","title":"feather/migrate","content":"","url":"feather/migrate.html"},{"doc":"feather","title":"Config","content":"pub type Config {\n  Config(\n    file: String,\n    journal_mode: JournalMode,\n    synchronous: SyncMode,\n    temp_store: TempStore,\n    mmap_size: Option(Int),\n    page_size: Option(Int),\n    foreign_keys: Bool,\n  )\n}\n\nConfig(\n  file: String,\n  journal_mode: JournalMode,\n  synchronous: SyncMode,\n  temp_store: TempStore,\n  mmap_size: Option(Int),\n  page_size: Option(Int),\n  foreign_keys: Bool,\n)\n\n\nSynonyms:\nfeather.Config\nfeather Config","url":"feather.html#Config"},{"doc":"feather","title":"JournalMode","content":"pub type JournalMode {\n  JournalDelete\n  JournalTruncate\n  JournalPersist\n  JournalMemory\n  JournalWal\n  JournalOff\n}\n\nJournalDelete\n\n\nJournalTruncate\n\n\nJournalPersist\n\n\nJournalMemory\n\n\nJournalWal\n\n\nJournalOff\n\n\nSynonyms:\nfeather.JournalMode\nfeather JournalMode","url":"feather.html#JournalMode"},{"doc":"feather","title":"SyncMode","content":"pub type SyncMode {\n  SyncExtra\n  SyncFull\n  SyncNormal\n  SyncOff\n}\n\nSyncExtra\n\n\nSyncFull\n\n\nSyncNormal\n\n\nSyncOff\n\n\nSynonyms:\nfeather.SyncMode\nfeather SyncMode","url":"feather.html#SyncMode"},{"doc":"feather","title":"TempStore","content":"pub type TempStore {\n  TempStoreDefault\n  TempStoreFile\n  TempStoreMemory\n}\n\nTempStoreDefault\n\n\nTempStoreFile\n\n\nTempStoreMemory\n\n\nSynonyms:\nfeather.TempStore\nfeather TempStore","url":"feather.html#TempStore"},{"doc":"feather","title":"connect","content":"pub fn connect(config: Config) -&gt; Result(Connection, Error)\n\nSynonyms:\nfeather.connect\nfeather connect","url":"feather.html#connect"},{"doc":"feather","title":"default_config","content":"pub fn default_config() -&gt; Config\n\nSynonyms:\nfeather.default_config\nfeather default_config","url":"feather.html#default_config"},{"doc":"feather","title":"disconnect","content":"pub fn disconnect(connection: Connection) -&gt; Result(Nil, Error)\n runs &quot;PRAGMA optimize;&quot; before closing the connection.\n If the connections are long-lived, then consider running\n this periodically anyways.\nSynonyms:\nfeather.disconnect\nfeather disconnect","url":"feather.html#disconnect"},{"doc":"feather","title":"main","content":"pub fn main() -&gt; Nil\n Runs the feather cli to generate new migrations and dump the schema\n you probably don&#39;t wanna run this yourself...\n run `gleam run -m feather` to find out more\nSynonyms:\nfeather.main\nfeather main","url":"feather.html#main"},{"doc":"feather","title":"optimize","content":"pub fn optimize(connection: Connection) -&gt; Result(Nil, Error)\n\nSynonyms:\nfeather.optimize\nfeather optimize","url":"feather.html#optimize"},{"doc":"feather","title":"with_connection","content":"pub fn with_connection(\n  config: Config,\n  fxn: fn(Connection) -&gt; a,\n) -&gt; Result(a, Error)\n Created a short lived connection, runs the included function on it,\n and then disconnects. If the connection could not be established,\n the callback function is not run, and this function returns an `Error`.\n\n This is particularly nice to use with use expressions:\n \n use connection &lt;- with_connection(default_config())\n\n let result = sqlight.query(...)\n \nSynonyms:\nfeather.with_connection\nfeather with_connection","url":"feather.html#with_connection"},{"doc":"feather","title":"feather","content":"","url":"feather.html"},{"doc":"feather/pool","title":"Pool","content":"pub type Pool(a) =\n  Subject(puddle.ManagerMessage(Connection, a))\n\n\nSynonyms:\nfeather/pool.Pool\nfeather/pool Pool","url":"feather/pool.html#Pool"},{"doc":"feather/pool","title":"start","content":"pub fn start(\n  config: Config,\n  count: Int,\n) -&gt; Result(Subject(ManagerMessage(Connection, a)), StartError)\n\nSynonyms:\nfeather/pool.start\nfeather/pool start","url":"feather/pool.html#start"},{"doc":"feather/pool","title":"with_connection","content":"pub fn with_connection(\n  pool: Subject(ManagerMessage(Connection, a)),\n  timeout: Int,\n  fxn: fn(Connection) -&gt; a,\n) -&gt; Result(a, Nil)\n\nSynonyms:\nfeather/pool.with_connection\nfeather/pool with_connection","url":"feather/pool.html#with_connection"},{"doc":"feather/pool","title":"with_transaction","content":"pub fn with_transaction(\n  pool: Subject(ManagerMessage(Connection, Result(a, Nil))),\n  timeout: Int,\n  fxn: fn(Connection) -&gt; Result(a, Nil),\n) -&gt; Result(a, Nil)\n This will panic if you end the transaction yourself!\nSynonyms:\nfeather/pool.with_transaction\nfeather/pool with_transaction","url":"feather/pool.html#with_transaction"},{"doc":"feather/pool","title":"feather/pool","content":"","url":"feather/pool.html"}]);